// ECMAScript 5 strict mode
"use strict";

assert2(cr, "cr namespace not created");
assert2(cr.plugins_, "cr.plugins_ not created");

cr.plugins_.VinoosTapsellPlus = function(runtime)
{
	this.runtime = runtime;
};

(function ()
{	
	var pluginProto = cr.plugins_.VinoosTapsellPlus.prototype;
		
/////////////////////////////////////
// Object type class
	pluginProto.Type = function(plugin)
	{
		this.plugin = plugin;
		this.runtime = plugin.runtime;
	};

	var typeProto = pluginProto.Type.prototype;

	var errorMessage = "";
	var responseId = "";
	
// called on startup for each object type
	typeProto.onCreate = function()
	{
		if(this.runtime.isBlackberry10 || this.runtime.isWindows8App || this.runtime.isWindowsPhone8 || this.runtime.isWindowsPhone81){
			var scripts=document.getElementsByTagName("script");
			var scriptExist=false;
			for(var i=0;i<scripts.length;i++){
				if(scripts[i].src.indexOf("cordova.js")!=-1||scripts[i].src.indexOf("phonegap.js")!=-1){
					scriptExist=true;
					break;
				}
			}
			if(!scriptExist){
				var newScriptTag=document.createElement("script");
				newScriptTag.setAttribute("type","text/javascript");
				newScriptTag.setAttribute("src", "cordova.js");
				document.getElementsByTagName("head")[0].appendChild(newScriptTag);
			}
		}
	};

/////////////////////////////////////
// Instance class
	pluginProto.Instance = function(type)
	{
		this.type = type;
		this.runtime = type.runtime;
	};
	
	var instanceProto = pluginProto.Instance.prototype;
	
	var isSupported = false;
	
// called whenever an instance is created
	instanceProto.onCreate = function()
	{
		if (!window["TapsellPlus"])
		{
			cr.logexport("[Construct 2] TapsellPlus plugin is required to show Admob ads with Cordova; other platforms are not supported");
			return;
		}
		
		isSupported = true;
		
		var self = this;
		
		var appKey = this.properties[0];
		
		TapsellPlus.initialize(appKey);
	
		document.addEventListener('response',function(data){
			responseId = data.responseId;
			switch(data.adType) {
				case 'interstitial':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onInterstitialAvailable, self);
					break;
				case 'rewardedVideo':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onRewardedVideoAvailable, self);
					break;
			}
		});
		
		document.addEventListener('error',function(data){
			errorMessage = data.message;
			switch(data.adType) {
				case 'interstitial':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onInterstitialNoAdAvailable, self);
					break;
				case 'rewardedVideo':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onRewardedVideoNoAdAvailable, self);
					break;
			}
		});
		
		document.addEventListener('onError',function(data){
			errorMessage = data.message;
			switch(data.adType) {
				case 'banner':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onBannerError, self);
					break;
				case 'interstitial':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onInterstitialError, self);
					break;
				case 'rewardedVideo':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onRewardedVideoError, self);
					break;
			}
		});
		
		document.addEventListener('onOpened',function(data){
			switch(data.adType) {
				case 'banner':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onBannerOpened, self);
					break;
				case 'interstitial':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onInterstitialOpened, self);
					break;
				case 'rewardedVideo':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onRewardedVideoOpened, self);
					break;
			}
		});
		
		document.addEventListener('onClosed',function(data){
			switch(data.adType) {
				case 'interstitial':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onInterstitialClosed, self);
					break;
				case 'rewardedVideo':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onRewardedVideoClosed, self);
					break;
			}
		});
		
		document.addEventListener('onRewarded',function(data){
			switch(data.adType) {
				case 'interstitial':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onInterstitialRewarded, self);
					break;
				case 'rewardedVideo':
					self.runtime.trigger(cr.plugins_.VinoosTapsellPlus.prototype.cnds.onRewardedVideoRewarded, self);
					break;
			}
		});

	};
	
	instanceProto.draw = function(ctx)
	{
	};
	instanceProto.drawGL = function (glw)
	{
	};

//////////////////////////////////////
// Conditions
	function Cnds() {};

	Cnds.prototype.onBannerOpened = function () {
		return true;
	};
	
	Cnds.prototype.onInterstitialAvailable = function () {
		return true;
	};
	
	Cnds.prototype.onRewardedVideoAvailable = function () {
		return true;
	};
	
	Cnds.prototype.onBannerError = function () {
		return true;
	};
	
	Cnds.prototype.onInterstitialNoAdAvailable = function () {
		return true;
	};
	
	Cnds.prototype.onRewardedVideoNoAdAvailable = function () {
		return true;
	};
	
	Cnds.prototype.onInterstitialError = function () {
		return true;
	};
	
	Cnds.prototype.onRewardedVideoError = function () {
		return true;
	};
	
	Cnds.prototype.onInterstitialOpened = function () {
		return true;
	};
	
	Cnds.prototype.onRewardedVideoOpened = function () {
		return true;
	};
	
	Cnds.prototype.onInterstitialClosed = function () {
		return true;
	};
	
	Cnds.prototype.onRewardedVideoClosed = function () {
		return true;
	};
	
	Cnds.prototype.onInterstitialRewarded = function () {
		return true;
	};
	
	Cnds.prototype.onRewardedVideoRewarded = function () {
		return true;
	};
	
	pluginProto.cnds = new Cnds();
	
//////////////////////////////////////
// Actions
	function Acts() {};
	
	Acts.prototype.createBanner = function (zoneid, position, size) {
		if (!isSupported)
			return;
		
		TapsellPlus.createBanner(zoneid, position, (size+1));
	};
	
	Acts.prototype.createBannerAtXY = function (zoneid, x, y, size) {
		if (!isSupported)
			return;
		
		TapsellPlus.createBannerAtXY(zoneid, x, y, (size+1));
	};
	
	Acts.prototype.removeBanner = function () {
		if (!isSupported)
			return;
		
		TapsellPlus.removeBanner();
	};
	
	Acts.prototype.showBanner = function () {
		if (!isSupported)
			return;
		
		TapsellPlus.showBanner();
	};
	
	Acts.prototype.hideBanner = function () {
		if (!isSupported)
			return;
		
		TapsellPlus.hideBanner();
	};
	
	Acts.prototype.requestRewardedVideo = function (zoneid) {
		if (!isSupported)
			return;
		
		TapsellPlus.requestRewardedVideo(zoneid);
	};
	
	Acts.prototype.requestInterstitial = function (zoneid) {
		if (!isSupported)
			return;
		
		TapsellPlus.requestInterstitial(zoneid);
	};
	
	Acts.prototype.showRewardedVideo = function (response_id) {
		if (!isSupported)
			return;
		
		TapsellPlus.showRewardedVideo(response_id);
	};
	
	Acts.prototype.showInterstitial = function (response_id) {
		if (!isSupported)
			return;
		
		TapsellPlus.showInterstitial(response_id);
	};
	
	pluginProto.acts = new Acts();
	
//////////////////////////////////////
// Expressions
	function Exps() {};

	Exps.prototype.ErrorMessage = function (ret) {
		ret.set_string(errorMessage);
	};

	Exps.prototype.ResponseId = function (ret) {
		ret.set_string(responseId);
	};
	
	pluginProto.exps = new Exps();

}());